import java.io.*;

class IO {

    // **********************************************************************
    // openFile
    //
    // given: fileName   the name of a file (a String)
    //
    // do:    Open the file for reading.
    //        Give an error message and quit if the file does not exist
    //        or cannot be read.
    // **********************************************************************
    public static StreamTokenizer openFile(String fileName) {
	File inFile = new File(fileName);
	if (!inFile.exists() || !inFile.canRead()) {
	    System.err.println("cannot open file "+fileName+" for reading");
	    System.exit(1);
	}
	try {
	    return (new StreamTokenizer(new BufferedReader(
						    new FileReader(inFile))));
	} catch (FileNotFoundException ex) {
	    // shound never happen
	    System.err.println("FileNodeFoundException caught in openFile");
	    System.exit(1);
	}
	return null; // can't get here but compiler complains if no return...
    }

    // **********************************************************************
    // readWord
    //
    // given: input   an input from which to read (a StreamTokenizer)
    //
    // do:    o read and return the next word from the input,
    //          ignoring white space and non-words in the file
    //          and converting the word to lower-case
    //        o return "" (the empty string) if at end of file
    //        o throw an IOException if an IOException is thrown by the read
    // **********************************************************************
    public static String readWord(StreamTokenizer input) throws IOException {
	input.lowerCaseMode(true);
	input.ordinaryChars('.', '.');
	if (input.nextToken() == StreamTokenizer.TT_EOF) {
	    return "";
	} else {
	    if (input.ttype != StreamTokenizer.TT_WORD) {
		// non-word: ignore it
		return readWord(input);
	    }
	    return(input.sval);
	}
    }

    // **********************************************************************
    // readInt
    //
    // given: input   an input from which to read (a StreamTokenizer)
    //
    // do:    o read and return the next integer from the input,
    //          ignoring white space and non-integers in the file
    //        o error (IOException) if at end of file
    //        o throw an IOException if an IOException is thrown by the read
    // **********************************************************************
    public static int readInt(StreamTokenizer input) throws IOException {
	if (input.nextToken() == StreamTokenizer.TT_EOF) {
	    throw new IOException();
	} else {
	    if (input.ttype != StreamTokenizer.TT_NUMBER) {
		// non-integer: ignore it
		return readInt(input);
	    }
	    return((int)input.nval);
	}
    }
}

