import java.io.*;
import java.util.*;

class ListClient {

    public static void main(String[] args) {
	ListInterface list;

	// make sure there are 2 command-line arguments
	if (args.length != 2) {
	    System.err.println("error:  Two arguments needed.");
	    System.err.println("usage:  java ListClient A|L file-of-strings");
	    System.exit(1);
	}

        if ( args[0].equals("A") )
	    list = new ListArray();
        else if ( args[0].equals("L") )
	    list = new ListLinked();
        else {
            System.err.println("error:  Incorrect first argument.");
	    System.err.println("usage:  java ListClient A|L file-of-strings");
            System.exit(1);

	    // bogus statement for compilation
	    list = new ListArray();
	}

	// Read the strings from the file, and put them in the list
	buildList(list, args[1]);
	System.out.println("-----------------");
	System.out.println("The initial list:");
	printList(list);
	System.out.println("-----------------");

	// Get interactive input to modify the list
	modifyList(list);



    } // end main




    //  buildList
    //  The is a file name.  The contents
    //  of the file are read, and contain strings which are used to
    //  build an initial list.
    private static void buildList(ListInterface theList, String filename) {
	String s;
	StreamTokenizer input;

	// open the file
	input = IO.openFile(filename);

	// read words from the file into list
	try {
	    s = IO.readWord(input);
	    while (! s.equals("")) {
		try {
		    theList.add(s);
		} catch (IndexOutOfBoundsException ex2){
	            System.err.println("Index out of bounds.");
	            System.exit(1);
		}
		s = IO.readWord(input);
	    }

	} catch (IOException ex1) {
	    System.err.println("Read failed.");
	    System.exit(1);
	}

    } // end BuildList




    //  printList
    //  prints the list, one string on its own line
    private static void printList(ListInterface theList) {
	int listSize;  // size of the list
	Object ob;     // pointer to one object in the list

	listSize = theList.size();
	for ( int i = 0; i < listSize; i++ ) {
	    ob = theList.get(i);
	    System.out.println((String) ob);
	}
    } // end printList



    //  modifyList
    //  gets interactive user input to cause a new string to be added
    //  to the list, or remove an entry in the list.  After each
    //  operation, the list is again printed, and the user is prompted
    //  for another operation.
    private static void modifyList(ListInterface theList) {

	boolean stopProgram = false;

	while (!stopProgram) {
	    System.out.println("Enter A (for add), R (for remove), or Q (for quit program)");
  	    try {
  	        String s = stdin.readLine();


  	        if ( (s.charAt(0) == 'A') || (s.charAt(0) == 'a') ) {
                    // for debugging 
		    // System.out.println("got an a");
		    addToList(theList);
	        } else if ( (s.charAt(0) == 'R') || (s.charAt(0) == 'r') ) {
                    // for debugging 
		    // System.out.println("got an r");
		    removeFromList(theList);
	        } else if ( (s.charAt(0) == 'Q') || (s.charAt(0) == 'q') ) {
                    // for debugging 
		    // System.out.println("got a q");
                    System.out.println("exiting program");
		    stopProgram = true;
	        } else {
  	            System.out.println("Bad input.  Only enter A or R.");
	        }
		if (!stopProgram) {
	            printList(theList);
	            System.out.println("-----------------");
		}
  	    } catch (IOException ex3) {
  	        System.err.println("Read of user input failed.");
  	        System.exit(1);
  	    }
        } // end while
    } // end modifyList


    private static final BufferedReader stdin = new BufferedReader(
        new InputStreamReader( System.in ) );



    //  addToList
    //  Prompts user for information about what to add to the list.
    //  This information includes the string and the position at which
    //  to place the string within the list.  0<=position<=size
    private static void addToList(ListInterface theList) {

	String s;
	System.out.println("Enter the string to be added to the list:");
        try{
  	    s = stdin.readLine();
	    System.out.println("Enter the position within the list:");
            try{
  	        String posString = stdin.readLine();
		int pos = Integer.parseInt(posString);
	        // turn the string into an integer 

	        // add this string to the list
                try {
	            theList.add(pos, s);
	        } catch (IndexOutOfBoundsException ex6) {
                    System.err.println("Invalid position.");
	        }
	    } catch (IOException ex5) {
                System.err.println("Read of position failed.");
                System.exit(1);
	    }
	} catch (IOException ex4) {
            System.err.println("Read of string failed.");
            System.exit(1);
	}

    }



    //  removeFromList
    //  Prompts user for information about which item to remove from
    //  the list. This information includes the position of the one to
    //  be removed.  0<=position<size
    private static void removeFromList(ListInterface theList) {
	System.out.println("Enter the integer position to be removed from the list:");
        try{
  	    String posString = stdin.readLine();
	    int pos = Integer.parseInt(posString);

	    // remove this position from the list
            try {
	        Object ob = theList.remove(pos);
	    } catch (IndexOutOfBoundsException ex6) {
                System.err.println("Invalid position.");
	    }
	} catch (IOException ex6) {
            System.err.println("Read of position failed.");
            System.exit(1);
	}
    }
   

} // end class ListClient
