/*
 * ListInterface.java
 * Created on January 23, 2004
 */

/**
 * Defines the methods that all Lists must implement.
 * @author  Karen Miller
 */
public interface ListInterface {

    /** Adds an object to the end of the list.
     *  @param ob The object to be added to the list.
     */
    public void add(Object ob);


    /** Adds an object at location given by position to the list,
     *  where the first item in the list is at position = 0. 
     *  @param ob The object to be added to the list.
     *  @throws IndexOutOfBoundsException if position < 0 or position > size() 
     */
    public void add(int position, Object ob);

    
    /** Returns the number of items currently in the list.
     *  @return the number of items in the list
     */
    public int size();
    

    /** Returns the object at position, after removing the object
     *  from the list. The first item in the list is at position = 0. 
     *  @param position The location of the object within the list.
     *  @return the object removed
     *  @throws IndexOutOfBoundsException if position<0 or position>size()-1 
     */
    public Object remove(int position);



    /** Returns the object at the given position, where the first
     *  item in the list is at position = 0.
     *  @param position The location of the object within the list.
     *  @return the object removed
     *  @throws IndexOutOfBoundsException if position < 0 or position > size()-1 
     */
    public Object get(int position);

}
